@@ -20,7 +20,7 @@ has options => sub {
 };
 has [qw(password username)] => '';
 
-our $VERSION = '1.07';
+our $VERSION = '1.08';
 
 sub db {
   my $self = shift;
@@ -96,7 +96,7 @@ Mojo::Pg - Mojolicious ♥ PostgreSQL
 
   # Create a table
   my $pg = Mojo::Pg->new('postgresql://postgres@/test');
-  $pg->db->do('create table if not exists names (name text)');
+  $pg->db->query('create table if not exists names (name text)');
 
   # Insert a few rows
   my $db = $pg->db;
@@ -273,6 +273,10 @@ connection. The L<DBD::Pg> database handle will be automatically cached again
 when that object is destroyed, so you can handle connection timeouts
 gracefully by holding on to it only for short amounts of time.
 
+  # Add up all the money
+  say $pg->db->query('select * from accounts')
+    ->hashes->reduce(sub { $a->{money} + $b->{money} });
+
 =head2 from_string
 
   $pg = $pg->from_string('postgresql://postgres@/test');
