@@ -7,6 +7,7 @@ use Mojo::IOLoop;
 use Mojo::JSON 'encode_json';
 use Mojo::Pg::Results;
 use Mojo::Pg::Transaction;
+use Mojo::Util 'deprecated';
 use Scalar::Util 'weaken';
 
 has [qw(dbh pg)];
@@ -34,7 +35,10 @@ sub disconnect {
   $self->dbh->disconnect;
 }
 
+# DEPRECATED!
 sub do {
+  deprecated 'Mojo::Pg::Database::do is DEPRECATED'
+    . ' in favor of Mojo::Pg::Database::query';
   my $self = shift;
   $self->dbh->do(@_);
   $self->_notifications;
@@ -233,6 +237,7 @@ Begin transaction and return L<Mojo::Pg::Transaction> object, which will
 automatically roll back the transaction unless
 L<Mojo::Pg::Transaction/"commit"> has been called before it is destroyed.
 
+  # Add names in a transaction
   my $tx = $db->begin;
   $db->query('insert into names values (?)', 'Baerbel');
   $db->query('insert into names values (?)', 'Wolfgang');
@@ -244,12 +249,6 @@ L<Mojo::Pg::Transaction/"commit"> has been called before it is destroyed.
 
 Disconnect L</"dbh"> and prevent it from getting cached again.
 
-=head2 do
-
-  $db = $db->do('create table foo (bar text)');
-
-Execute a statement and discard its result.
-
 =head2 dollar_only
 
   $db = $db->dollar_only;
@@ -257,6 +256,7 @@ Execute a statement and discard its result.
 Activate C<pg_placeholder_dollaronly> for next L</"query"> call and allow C<?>
 to be used as an operator.
 
+  # Check for a key in a JSON document
   $db->dollar_only->query('select * from foo where bar ? $1', 'baz')
     ->expand->hashes->map(sub { $_->{bar}{baz} })->join("\n")->say;
 
